<?php 

namespace Teknisa\MAN\Controllers\DataExporterImpl;

use Zeedhi\Framework\DTO\Response;
use Teknisa\MAN\Controllers\DataExporterImpl\ReportHandlers;
use Teknisa\MAN\Services\RelVendasProdutoPeriodoporModo;

class ReportHandlerFactory implements IReportHandlerFactory {
    const VENDAS_REALIZADAS_PERIODO     = 'vnd41208Q_relVendasRealizadasPeriodoDataExporter';
    const KDS_TEMPO_PRODUCAO            = 'orm00021_relSetorProducaoKDS';
    const DESCONTOS_CONCEDIDOS          = 'vnd55007_relDescConcedidosExport';
    const KDS_TEMPO_TOTAL               = 'vnd55013_tempoProducaoKDS';
    const CUPONS_SATNFCE                = 'vnd4120Y_relRelacaoCuponsSatExport';
    const DESCONTOS_POR_TIPO_CONSUMIDOR = 'vnd55017_relDecontosTipoConsumidorExport';
    const PRODUTOSPORMODALIDADE         = 'vnd55008_relVendasProdutoPeriodoporModoExport';
    const ENTREGAS_MOTOBOY              = 'orm00006_relEntregasPorMotoboyExport';
    const VND_DLV_OPERADOR              = 'vnd0160L_RelVendasDlvOperaExport';
    const OBSERVACAO_DESCONTO           = 'vnd0160K_relObservacaoDescontoExport';
    const PROD_MOD_TIPOCONS             = 'vnd55020_relProdModTipoconsExport';
    const LOG_CONTROLE_DE_ACESSO        = 'vnd62000_relLogControleDeAcessoExport';
    const VENDA_DIA_HORA                = 'vnd02500_relVendasDiaHoraExport';
    
    protected $relService;
    protected $relatorioService;
    
    public function __construct ($relService, RelVendasProdutoPeriodoporModo $relatorioService) {
        $this->relService = $relService;
        $this->relatorioService = $relatorioService;
        
    }
    
    public function getReportHandler($dataSourceName) {
        if($dataSourceName === self::VENDAS_REALIZADAS_PERIODO) {
            return new ReportHandlers\VendasRealizadasReportHandler($this->relService);
        } if($dataSourceName === self::DESCONTOS_CONCEDIDOS) {
            return new ReportHandlers\DescontosConcedidosReportHandler($this->relService);
        } if($dataSourceName === self::KDS_TEMPO_PRODUCAO) {
            return new ReportHandlers\RelSetorProducaoKDSReportHandler($this->relService);
        } if($dataSourceName === self::KDS_TEMPO_TOTAL) {
            return new ReportHandlers\RelTempoProducaoKDSReportHandler($this->relService);
        } if($dataSourceName === self::CUPONS_SATNFCE) {
            return new ReportHandlers\RelRelacaoCuponsSatReportHandler($this->relService);
        } if($dataSourceName === self::DESCONTOS_POR_TIPO_CONSUMIDOR) {
            return new ReportHandlers\DescontosTipoConsumidorReportHandler($this->relService);
        } if($dataSourceName === self::PRODUTOSPORMODALIDADE) {
            return new ReportHandlers\RelVendasProdutoPeriodoporModoReportHandler($this->relService, $this->relatorioService);
        } if($dataSourceName === self::ENTREGAS_MOTOBOY) {
            return new ReportHandlers\RelEntregasPorMotoboyHandler($this->relService, $this->relatorioService);
        } if($dataSourceName === self::VND_DLV_OPERADOR) {
            return new ReportHandlers\RelVendasDlvOperaHandler($this->relService, $this->relatorioService);
        } if($dataSourceName === self::OBSERVACAO_DESCONTO) {
            return new ReportHandlers\RelObservacaoDescontoHandler($this->relService, $this->relatorioService);
        } if($dataSourceName === self::PROD_MOD_TIPOCONS) {
            return new ReportHandlers\RelProdModTipoconsReportHandler($this->relService, $this->relatorioService);
        } if($dataSourceName === self::LOG_CONTROLE_DE_ACESSO) {
            return new ReportHandlers\RelLogControleDeAcessoReportHandler($this->relService, $this->relatorioService);
        } if($dataSourceName === self::VENDA_DIA_HORA) {
            return new ReportHandlers\RelVendaDiaHoraReportHandler($this->relService, $this->relatorioService);
        } else {
            return null;
        }
    }
}