<?php
namespace Teknisa\MAN\Controllers;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Teknisa\MAN\Services\RelVendProdCompConsService;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO\Response\Error;   

class RelVendProdCompConsController  extends  CrudWithParameterBag { 
    
    protected $relatorioService;
    protected $utilService,
              $parameterBagColumns = array('NRORG');
    protected $formatBirt;
              
    public function __construct ($crudService, $parameterBag, $entityManager, Utilities\Util $utilService, Manager $dataSourceManager,
                                 RelVendProdCompConsService $vendProduCompConsService, BirtReport $birtReport, ReportService $reportService, $relatorioService) {
        $this->crudService                  = $crudService;
        $this->parameterBag                 = $parameterBag;
        $this->entityManager                = $entityManager;
        $this->utilService                  = $utilService;
        $this->dataSourceManager            = $dataSourceManager;
        $this->vendProduCompConsService       = $vendProduCompConsService;
        $this->birtReport                   = $birtReport;
        $this->reportService                = $reportService;
        $this->relatorioService             = $relatorioService;
    }
    
    public function findRelatorio(DTO\Request\Row $request, DTO\Response $response) {
        $conditions = $this->utilService->getParamsAsArray($request);
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'CDFILICAIXA', 'CDCAIXA');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'FILILOJA', 'CDLOJA');
        $this->relatorioService->setTCDandCDChangingKey($conditions, 'BIRTABRTFORMAT', 'DTABERTUR');
        $this->relatorioService->setCustomDate($conditions, 'DTENTRVENDA', 'DATAINI', 'DATAFIN');
        $this->formatBirt = 'pdf';
        
        $params = $this->vendProduCompConsService->vendProdCompConsParamBuild($conditions);
        $this->getReport($params, $response);
    }
    
    public function getReport($params, DTO\Response $response){
        try {
            $birtURL = $this->reportService->createRemoteReport('BIRT', $params['ReportName'], $params['ParametersRow']);
            if ($this->formatBirt === 'xls') {
                $birtURL = str_replace('pdf', 'xls', $birtURL);
            }
            $response->addDataset(new DataSet('URL',array('url'=>$birtURL)));
        
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage() , 500));
        }
    }
    
}